# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from . import _utilities
import typing
# Export this package's modules as members:
from .provider import *

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_terraform.state as __state
    state = __state
else:
    state = _utilities.lazy_import('pulumi_terraform.state')

_utilities.register(
    resource_modules="""
[]
""",
    resource_packages="""
[
 {
  "pkg": "terraform",
  "token": "pulumi:providers:terraform",
  "fqn": "pulumi_terraform",
  "class": "Provider"
 }
]
"""
)
